@@ -27,15 +27,19 @@ import webview
 import webview.menu as wm
 import jedi  # noqa # type: ignore
 
+import librepythonista_py_edit
+
 
 # https://pywebview.flowrl.com/guide/api.html#webview-settings
 
-webview.settings = {
-    "ALLOW_DOWNLOADS": False,
-    "ALLOW_FILE_URLS": True,
-    "OPEN_EXTERNAL_LINKS_IN_BROWSER": False,
-    "OPEN_DEVTOOLS_IN_DEBUG": False,
-}
+webview.settings.update(
+    {
+        "ALLOW_DOWNLOADS": False,
+        "ALLOW_FILE_URLS": True,
+        "OPEN_EXTERNAL_LINKS_IN_BROWSER": False,
+        "OPEN_DEVTOOLS_IN_DEBUG": False,
+    }
+)
 
 _WEB_VEW_ENDED = False
 _IS_DEBUG = False
@@ -745,6 +749,7 @@ def main():
             "cmd": "request_action",
             "process_id": process_id,
             "action": "get_info",
+            "version": librepythonista_py_edit.__version__,
             "params": {},
         }
         send_message(client_socket, request_data)
